#
# spec file for package skopeo
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#
# nodebuginfo

# Don't enable ostree by default, as libostree is only available in tumbleweed.
%bcond_with ostree
# Don't enable storage by default, as it's not really widely used (and it's
# also an _incredibly_ dodgy feature -- it effectively is used to hack around
# Docker's graphdrivers).
%bcond_with storage

Name:           skopeo
Version:        0.1.26
Release:        lp150.2.3
Summary:        Container image repository tool
License:        Apache-2.0
Group:          System/Management
Url:            https://github.com/projectatomic/skopeo
Source:         %{name}-%{version}.tar.xz
BuildRequires:  go >= 1.5
BuildRequires:  go-go-md2man
BuildRequires:  libgpgme-devel
# Required for containers/storage integration.
%if 0%{with storage}
BuildRequires:  device-mapper-devel >= 1.2.68
BuildRequires:  glib2-devel
BuildRequires:  libbtrfs-devel >= 3.8
%endif
%if 0%{with ostree}
BuildRequires:  libostree-devel
%endif
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
ExcludeArch:    s390

%description
skopeo is a command line utility for various operations on container images and
image repositories. skopeo is able to inspect a repository on a Docker registry
and fetch images layers. skopeo can copy container images between various
storage mechanisms.

%prep
%setup -q

%build
mkdir -p .gopath/src/github.com/projectatomic
ln -s $PWD .gopath/src/github.com/projectatomic/skopeo
export GOPATH=$PWD/.gopath

export BUILDTAGS="exclude_graphdriver_aufs"
%if 0%{?suse_version} <= 1320
	BUILDTAGS+=" libdm_no_deferred_remove"
%endif
%if ! 0%{with ostree}
	BUILDTAGS+=" containers_image_ostree_stub"
%endif
%if ! 0%{with storage}
	BUILDTAGS+=" containers_image_storage_stub"
%endif

# Build.
go build -buildmode=pie -ldflags "-X main.gitCommit=" -gcflags "" -tags "$BUILDTAGS" -o skopeo github.com/projectatomic/skopeo/cmd/skopeo
make docs

%install
# Install the binary.
install -D -m 0755 %{name} "%{buildroot}/%{_bindir}/%{name}"
install -D -m 0644 default-policy.json "%{buildroot}/etc/containers/policy.json"
make INSTALLDIR="%{buildroot}/%{_bindir}" install-binary

# Install the docs.
make MANINSTALLDIR="%{buildroot}/%{_mandir}" install-docs

%files
%defattr(-,root,root)
%doc LICENSE README.md
%{_bindir}/%{name}
%dir /etc/containers
%config /etc/containers/policy.json
%{_mandir}/man1/skopeo.1*

%changelog
* Thu Feb  1 2018 ro@suse.de
- do not build on s390, only on s390x (no go on s390)
* Mon Nov 20 2017 asarai@suse.com
- Update to skopeo v0.1.26. This includes a fix for CVE-2017-14992.
- Disable containers/storage integration by default (through
  containers_image_storage_stub), as it is very dodgy and not widely used.
* Sun Oct 22 2017 asarai@suse.com
- Update to skopeo v0.1.24. Upstream changelog:
  * Improvements to macOS builds: A make binary-local should work without extra options.
  * make install on macOS now installs to /usr/local
  * The destination in docker-archive: now can be a pipe.
  * When building with containers_image_openpgp, signatures with PGP v3 signature packets are accepted.
  * Unreadable /etc/docker/certs.d now only logs a warning instead of aborting the operation.
  * oci-layout: naming semantics changes:
  * A full range of org.opencontainers.image.ref.name values is now accepted
  * A name must be specified for oci-layout: destinations (it does not default to latest any more).
  * For oci-layout: sources, a name is now optional if the image index contains exactly one image (instead of using the image with the latest name).
  * Policy configuration identities of oci-layout: images now consist only of the directory name, to avoid the ambiguity created by the unspecified annotation values above.
  * ~/.docker/config.json credential helpers (configured in credHelpers) are now supported.
  * Annotations are now preserved when copying and compressing OCI images.
  * New transport oci-archive:, works exactly like oci-layout:, but works on tarballs instead of extracted directories.
  * When copying images, skopeo always asks for the same image schema, and optionally converts the image itself to make it acceptable to the destination, instead of asking for a schema dependent on the destinations’ capabilities (relying on the source to convert the image).
  * Improved installation instructions.
  * ostree: image names can now contain colons (e.g. port specifications)
  * skopeo now does not declare support for manifest lists, so that the source registry provides a single image. This allows skopeo copy to copy various images recently published to Docker Hub. (More complete support for manifest lists will come in the future.)
  * The containers-storage: backend has been updated, incl. support for the override_kernel_checks option.
  * Improved the output of progress bars in skopeo copy.
  * Fixed fetching blobs with external URLs in images served by docker/distribution registries.
  * OCI images now support reading blobs with external URLs, ands storing information about such blobs without copying the contents.
  * Writing ostree: images creates a docker.digest annotation.
  * docker/distribution registry credentials are now read from $XDG_RUNTIME_DIR/containers/auth.json before trying ~/.docker/config.json and ~/.dockercfg.
  * skopeo inspect no longer crashes on images where the config blob does not contain a container configuration.
* Wed Sep  6 2017 asarai@suse.com
- Add -buildmode=pie to fix bugs building on ppc64le.
* Sat Jul 22 2017 asarai@suse.com
- Update to skopeo v0.1.23. This supports OCI v1, as well as a variety of new
  transports such as docker-archive and ostree.
- Disable ostree builds by default with %%bcond_with, as only Tumbleweed has
  libostree and we need skopeo for KIWI.
* Fri Apr 14 2017 asarai@suse.com
- Update to skopeo 0.1.19, which supports 1.0.0-rc4 of the image-spec as well
  as all of our patches have been merged upstream.
  - 0001-docker-split-tarfile-code-from-docker-daemon-code.patch
  - 0002-docker-add-docker-archive-transport.patch
  - 0003-squashme-docker-tarfile-make-tagging-work-properly.patch
  - 0004-squashme-docker-archive-handle-mtrmac-s-comments.patch
  - 0005-squashme-docker-archive-correctly-handle-tagging.patch
  - 0006-copy-move-compression-to-separate-pkg.patch
  - 0007-docker-daemon-decompress-blobs-transparently-in-GetB.patch
  - oci-remove-MIME-type-autodetection.patch
* Wed Feb 15 2017 asarai@suse.com
- Add further patches to handle OCI <-> Docker translation properly. This is
  necessary for KIWI integration. https://github.com/containers/image/pull/237
  + oci-remove-MIME-type-autodetection.patch
* Tue Feb  7 2017 asarai@suse.com
- Add buildtags to handle the Docker-like buildtags such as
  libdm_no_deferred_remove and exclude_graphdriver_aufs.
* Tue Feb  7 2017 asarai@suse.com
- Add patches for docker-archive transport.
  + 0001-docker-split-tarfile-code-from-docker-daemon-code.patch
  + 0002-docker-add-docker-archive-transport.patch
  + 0003-squashme-docker-tarfile-make-tagging-work-properly.patch
  + 0004-squashme-docker-archive-handle-mtrmac-s-comments.patch
  + 0005-squashme-docker-archive-correctly-handle-tagging.patch
  + 0006-copy-move-compression-to-separate-pkg.patch
  + 0007-docker-daemon-decompress-blobs-transparently-in-GetB.patch
* Tue Feb  7 2017 asarai@suse.com
- Bump to skopeo v0.1.18. Many updates to containers/image, and fixes to the
  Docker v2s2 schema conversion.
* Tue Dec 13 2016 asarai@suse.com
- Bump to skopeo v0.1.17. This version includes many, many fixes to OCI image
  handling as well as adding features such as the docker-daemon: transport.
  There are also several UX fixes to how passwords are managed.
* Thu Dec  8 2016 asarai@suse.com
- Bump to v0.1.16+r54 (a865c07818ed914e2602205be6e9d67debc1d660). This is
  necessary so that we don't need to do major backporting of containers/image.
  skopeo intends to bump themselves to v0.1.17 in the coming week so this is
  just a temporary measure.
- Removed patches no longer needed.
  - oci-fix-mediatypes.patch
* Fri Nov 11 2016 asarai@suse.com
- Backport OCI mediatype fixes. https://github.com/projectatomic/skopeo/pull/221
  + oci-fix-mediatypes.patch
* Fri Nov 11 2016 asarai@suse.com
- Initial import of skopeo v0.1.16.
